
from setuptools import setup

setup(
    name="signalepy",
    description="An Elegant Console Logger For Python",
    long_description=open("./README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/ShardulNalegave/signalepy",
    version="0.1.1",
    author="Shardul Nalegave",
    author_email="nalegaveshardul40@gmail.com",
    license="MIT",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Environment :: Console"
    ]
)
